PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Layer.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Functions
Layer.hpp File Reference
`#include "Defs.hpp"`
`#include "Py.hpp"`
`#include "Enums.hpp"`

Go to the source code of this file.

## Data Structures
class | Layer

## Functions
uint | cutLayersFromRange (uint &zmin, uint &zmax, uint C0, uint C1)
bool | adjustIndexForCutLayers (uint &z, uint C0, uint C1)

## Function Documentation

## ◆ adjustIndexForCutLayers()

bool adjustIndexForCutLayers | ( | uint & | z,
|  | uint | C0,
|  | uint | C1 )
| inline

## ◆ cutLayersFromRange()

uint cutLayersFromRange | ( | uint & | zmin,
|  | uint & | zmax,
|  | uint | C0,
|  | uint | C1 )
| inline